@@ -17,6 +17,7 @@ import bossa.syntax.*;
 import gnu.bytecode.*;
 import gnu.expr.*;
 import nice.tools.code.Import;
+import nice.tools.typing.PrimitiveType;
 
 import java.util.*;
 import java.util.jar.*;
@@ -28,7 +29,7 @@ import gnu.expr.ClassExp;
 /**
    A Nice package.
    
-   @version $Date: 2004/06/11 15:58:58 $
+   @version $Date: 2005/02/20 21:20:02 $
    @author Daniel Bonniot (bonniot@users.sourceforge.net)
  */
 public class Package implements mlsub.compilation.Module, Located, bossa.syntax.Module
@@ -61,8 +62,8 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
   /****************************************************************
    * Single Constructor
    ****************************************************************/
-  
-  private Package(LocatedString name, 
+
+  private Package(LocatedString name,
 		  Compilation compilation,
 		  boolean isRoot)
   {
@@ -76,26 +77,29 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     if (source == null)
       User.error(name, "Could not find package " + name);
 
-    loadImports();
+    boolean shouldReload =
+      compilation.recompileAll ||
+      isRoot && compilation.recompileCommandLine;
+
+    loadImports(shouldReload);
 
     prepareCodeGeneration();
 
-    read(compilation.recompileAll || 
-	 isRoot && compilation.recompileCommandLine);
+    read(shouldReload);
   }
 
-  private void loadImports()
+  private void loadImports(boolean shouldReload)
   {
     Set opens = new TreeSet();
     opens.add("java.lang");
     opens.add("java.util");
 
-    imports = source.getImports(opens);
+    imports = source.getImports(opens, shouldReload);
 
     if (!name.toString().equals("nice.lang") && !Debug.ignorePrelude)
-      imports.add(new LocatedString("nice.lang", 
+      imports.add(new LocatedString("nice.lang",
 				    bossa.util.Location.nowhere()));
-    
+
     setOpens(opens);
 
     List p = this.getImports();
@@ -115,8 +119,8 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     compilation.progress(this, "parsing");
 
     definitions = new ArrayList();
-    source.getDefinitions(definitions, shouldReload, compilation.storeDocStrings);
-    this.ast = new AST(this, definitions);
+    source.getDefinitions(definitions, shouldReload);
+    this.ast = bossa.syntax.dispatch.createAST(this, definitions);
     definitions = null;
     compilation.addNumberOfDeclarations(ast.numberOfDeclarations());
 
@@ -150,7 +154,7 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     for(Method method = source.getBytecode().getMethods();
 	method != null;
 	method = method.getNext())
-      bossa.link.ImportedAlternative.read(source.getBytecode(), method,
+      bossa.syntax.dispatch.readImportedAlternative(source.getBytecode(), method,
 					  location());
   }
   
@@ -283,11 +287,12 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     mlsub.typing.Typing.startNewCompilation();
     nice.tools.code.Types.reset();
     nice.tools.code.SpecialTypes.init();
-    bossa.link.Alternative.reset();
-    bossa.link.Dispatch.reset();
-    ClassDefinition.reset();
-    TypeConstructors.reset();
-    JavaClasses.reset();
+    bossa.syntax.dispatch.resetAlternatives();
+    bossa.syntax.dispatch.resetDispatchTest();
+    bossa.syntax.dispatch.resetTypeDefinitionMappings();
+    bossa.syntax.dispatch.resetConstructorsMap();
+    bossa.syntax.dispatch.resetJavaClasses();
+    PrimitiveType.reset();
     gnu.bytecode.Type.reset();
   }
 
@@ -334,7 +339,7 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     if (compiling())
       {
         compilation.progress(this, "linking");
-	bossa.link.Dispatch.test(this);
+	bossa.syntax.dispatch.testCoverage(this);
 
 	finishCompilation();
 
@@ -346,6 +351,8 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     // Write the archive even if nothing was compiled.
     // This is useful to bundle the application after it was compiled.
     writeArchive();
+
+    compilation.locator.save();
   }
 
   /**
@@ -511,7 +518,7 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
   throws IOException
   {
     JarFile runtime = null;
-    
+
     if (runtimeJar != null)
       try {
 	runtime = new JarFile(runtimeJar);
@@ -561,7 +568,7 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
       ((Package) i.next()).addToArchive(jarStream, linkPerformed);
   }
 
-  private static void addEntry(String name, InputStream data, 
+  private static void addEntry(String name, InputStream data,
 			       JarOutputStream out)
   throws IOException
   {
@@ -575,7 +582,7 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     int size = in.available();
     if (size < 1024) size = 1024;
     byte[] buf = new byte[size];
-    
+
     try{
       int read;
       do
@@ -590,40 +597,40 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
       in.close();
     }
   }
-  
+
   /****************************************************************
    * Code generation
    ****************************************************************/
 
   /** The name of the class package functions and method implementations
-      are stored in. 
+      are stored in.
   **/
   static final String packageClassName = "fun";
 
-  public ClassExp getClassExp(NiceClass def)
+  public ClassExp getClassExp(Object def)
   {
     if (compiling())
-      return def.createClassExp();
-    
-    String name = def.getName().toString();
+      return bossa.syntax.dispatch.NiceClass_createClassExp(def);
+
+    String name = bossa.syntax.dispatch.NiceClass_getName(def).toString();
     ClassType classe = source.readClass(name);
     if (classe == null)
       Internal.error("Compiled class " + def + " was not found");
     importMethods(def, classe);
-    
+
     ClassExp res = new ClassExp(classe);
     addUserClass(res);
     return res;
   }
 
   /** Load methods compiled in a class (custom constructors for now). */
-  private void importMethods(NiceClass def, ClassType classe)
+  private void importMethods(Object def, ClassType classe)
   {
     for(Method method = classe.getMethods();
 	method != null;
 	method = method.getNext())
       {
-        Definition d = CustomConstructor.load(def, method);
+        Definition d = bossa.syntax.dispatch.NiceClass_importMethod(def, method);
         if (d != null)
           definitions.add(d);
       }
@@ -638,8 +645,7 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
       classe.outer = getImplementationClass();
   }
 
-  public void addGlobalVar(gnu.expr.Declaration decl, 
-                           boolean constant)
+  public void addGlobalVar(gnu.expr.Declaration decl, boolean constant)
   {
     if (!compiling())
       // The code is already there
@@ -669,9 +675,6 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     res.setName(name);
     res.setSimple(true);
     res.body = QuoteExp.voidExp;
-    // This is not true, but useful to make some Java-centric tools happy.
-    // The real file info in the the SourceDebugExtension attribute.
-    res.setFile(name.substring(name.lastIndexOf('.') + 1) + ".nice");
     res.needsConstructor = true;
     return res;
   }
@@ -737,6 +740,11 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
     return res;
   }
 
+  public Method lookupDispatchClassMethod(String name, String attribute, String value)
+  {
+    return lookupClassMethod(source.getDispatch(), name, attribute, value);
+  }
+
   /**
      @return the bytecode method with this (unique) name
      if the package has not been recompiled.
@@ -766,73 +774,6 @@ public class Package implements mlsub.compilation.Module, Located, bossa.syntax.
 
     return null;
   }
-  
-  public gnu.expr.Expression getDispatchMethod(NiceMethod def)
-  {
-    String name = def.getName().toString();
-    LambdaExp res;
-    Type[] argTypes;
-    Type retType;
-
-    /*
-      If this package is not recompiled,
-      we fetch the bytecode type information
-      from the previous dispatch class.
-      Benefits: we get the most precise bytecode type for methods,
-        as computed during the initial compilation.
-        This would not be the case if we recomputed it,
-	as the precise types are found during typechecking.
-    */
-    Method meth = lookupClassMethod(source.getDispatch(), name,
-				    "id", def.getFullName());
-    if (meth != null) // Reuse existing dispatch method header
-      {
-	// The dispatch code will have to be regenerated anyway
-	meth.eraseCode();
-
-	argTypes = meth.arg_types;
-	retType  = meth.return_type;
-        // Make sure we use the same bytecode name, since compiled code
-        // can rely on it.
-        name = meth.getName();
-      }
-    else // Get type information from the nice declaration
-      {
-	argTypes = def.javaArgTypes();
-	retType  = def.javaReturnType();
-      }
-
-    // Try to compile the dispatch method as a member method if possible.
-    NiceClass receiver;
-    if (argTypes.length == 0)
-      receiver = null;
-    else
-      {
-        receiver = NiceClass.get(def.getArgTypes()[0]);
-
-        // JVM interfaces cannot contain code.
-        if (receiver != null && receiver.isInterface())
-          receiver = null;
-
-        // Special treatment for serialization at the moment.
-        if (def.getArity() == 2 && 
-            (name.equals("writeObject")||name.equals("readObject")))
-          receiver = null;
-      }
-
-    res = nice.tools.code.Gen.createMethod
-      (name, argTypes, retType, def.getSymbols(), true, receiver != null);
-    res.parameterCopies = def.formalParameters().getParameterCopies();
-
-    // add unique information to disambiguate which method this represents
-    res.addBytecodeAttribute
-      (new MiscAttr("id", def.getFullName().getBytes()));
-
-    if (receiver != null)
-      return receiver.addJavaMethod(res);
-    else
-      return addMethod(res, false);
-  }
 
   /** Add a method to this package and return an expression to refer it. */
   public ReferenceExp addMethod(LambdaExp method, boolean packageMethod)
