@@ -15,7 +15,7 @@ package bossa.syntax;
 /**
    A Nice module.
 
-   @version $Date: 2004/03/05 14:07:14 $
+   @version $Date: 2005/01/14 11:12:10 $
    @author Daniel Bonniot
  */
 
@@ -31,9 +31,9 @@ public interface Module extends mlsub.compilation.Module
 
   gnu.bytecode.ClassType createClass(String name);
   void addGlobalVar(gnu.expr.Declaration declaration, boolean constant);
-  gnu.expr.Expression getDispatchMethod(NiceMethod def);
+  gnu.bytecode.Method lookupDispatchClassMethod(String name, String attribute, String value);
   gnu.expr.ReferenceExp addMethod(gnu.expr.LambdaExp method, 
 				  boolean packageMethod);
-  gnu.expr.ClassExp getClassExp(NiceClass def);
+  gnu.expr.ClassExp getClassExp(Object def);
   void addUserClass(gnu.expr.ClassExp classe);
 }
