@@ -20,7 +20,7 @@ import mlsub.typing.TypeSymbol;
    Basic component of the syntax tree.
    Defines its local scope.
    
-   @version $Date: 2004/06/17 12:15:50 $
+   @version $Date: 2005/01/13 16:47:33 $
    @author Daniel Bonniot (d.bonniot@mail.dotcom.fr) 
 */
 abstract public class Node
@@ -69,6 +69,11 @@ abstract public class Node
 
     children.remove(n);
   }
+
+  void removeChildren()
+  {
+     children = null;
+  }
   
   /**
    * Always returns the argument (except an empty list for 'null').
@@ -85,7 +90,7 @@ abstract public class Node
     return c;
   }
 
-  void addSymbol(VarSymbol s)
+  void addSymbol(/*VarSymbol*/Symbol s)
   {
     if (varSymbols == null)
       varSymbols = new ArrayList();
@@ -96,17 +101,7 @@ abstract public class Node
   {
     addTypeMap(s.toString(), s);
   }
-  
-  void addTypeSymbols(Collection c)
-  {
-    if(c!=null)
-      for(Iterator i=c.iterator(); i.hasNext();)
-	{
-	  TypeSymbol s = (TypeSymbol) i.next();
-	  addTypeMap(s.toString(), s);
-	}
-  }
-  
+
   void addTypeMap(String name, TypeSymbol symbol)
   {
     if (typeMapsNames == null)
@@ -122,29 +117,41 @@ abstract public class Node
    * Scopes shared by all modules.
    */
 
-  private static GlobalVarScope globalScope;
-  public static final GlobalVarScope getGlobalScope()
+  private static VarScope globalScope;
+  public static final VarScope getGlobalScope()
   {
     return globalScope;
   }
   
-  private static GlobalTypeScope globalTypeScope;
-  public static final GlobalTypeScope getGlobalTypeScope()
+  private static TypeScope globalTypeScope;
+  public static final TypeScope getGlobalTypeScope()
   {
     return globalTypeScope;
   }
-  
+
+  public static final Module getGlobalTypeScopeModule()
+  {
+    return globalTypeScope.getModule();
+  }
+
+  public static mlsub.typing.TypeConstructor globalTypeScopeLookup(String name, Location loc)
+  {
+    return globalTypeScope.globalLookup(name, loc);
+  }
+
+  public static bossa.modules.Compilation compilation = null;
+
   public static void setModule(Module module)
   {
     // For multiple compilations in the same JVM:
     // If we are starting a new compilation, reset the global scopes.
-    if (JavaClasses.compilation != module.compilation())
+    if (compilation != module.compilation())
       {
-	JavaClasses.compilation = module.compilation();
-	globalScope = new GlobalVarScope();
-	globalTypeScope = new GlobalTypeScope();
+        compilation = module.compilation();
+	globalScope = dispatch.createGlobalVarScope();
+	globalTypeScope = dispatch.createGlobalTypeScope();
       }
-    globalTypeScope.module = module;
+    globalTypeScope.setModule(module);
   }
 
   void buildScope(Module module)
@@ -273,9 +280,9 @@ abstract public class Node
 
   // The current function should be saved in nodes that need it
   // during execution of their typecheck method.
-  static Function currentFunction;
-  static Function getCurrentFunction() { return currentFunction; }
-  static void setCurrentFunction(Function f) { currentFunction = f; }
+  static /*Function*/Object currentFunction;
+  static /*Function*/Object getCurrentFunction() { return currentFunction; }
+  static void setCurrentFunction(/*Function*/Object f) { currentFunction = f; }
   
   /** The this parameter of the current function, or null. */
   static Expression thisExp;
@@ -302,7 +309,7 @@ abstract public class Node
           ((Node)i.next()).doTypecheck();
         }
         catch(UserError ex){
-          globalTypeScope.module.compilation().error(ex);
+          globalTypeScope.getModule().compilation().error(ex);
 	}
   }
 
