@@ -30,7 +30,8 @@ public class CatchClause extends ScopeExp
     Declaration catchDecl = firstDecl();
     Variable catchVar = catchDecl.allocateVariable(code);
     code.enterScope (scope);
-    code.emitCatchStart(catchVar);
+    code.emitCatchStart((ClassType) catchDecl.getType());
+    catchDecl.compileStore(comp);
     body.compileWithPosition(comp, target);
     code.emitCatchEnd();
     code.popScope ();
