@@ -32,7 +32,7 @@ public class ExitExp extends Expression
     CodeAttr code = comp.getCode();
     Expression res = result == null ? QuoteExp.voidExp : result;
     res.compileWithPosition(comp, block.subTarget);
-    code.emitGoto(block.exitLabel);
+    block.exit(code);
   }
 
   protected Expression walk (ExpWalker walker)
