@@ -480,15 +480,22 @@ public class LambdaExp extends ScopeExp
     gnu.bytecode.CodeAttr code = comp.getCode();
     if (! getInlineOnly())
       {
-	if (comp.method.reachableHere() 
+	if (comp.method.reachableHere()
 	    /* Work-around since reachableHere is not computed properly:
-	       Only return if the method is void or if there is a value 
+	       Only return if the method is void or if there is a value
 	       on the stack.
 	    */
-	    && (comp.method.getReturnType().isVoid() || code.SP > 0)
+	    && (code.SP > 0 || comp.method.getReturnType().isVoid())
 	    && (! Compilation.usingTailCalls
 		|| isModuleBody() || isClassMethod() || isHandlingTailCalls()))
-	  code.emitReturn();
+	  {
+            // The line of a method is by convention it's last one,
+            // specifically to make this feature possible.
+            if (getLine() > 0)
+              code.putLineNumber(getFile(), getLine());
+
+            code.emitReturn();
+          }
 	code.popScope();        // Undoes enterScope in allocParameters
       }
     if (! Compilation.fewerClasses) // FIXME
@@ -997,7 +1004,8 @@ public class LambdaExp extends ScopeExp
                 // Make sure the name is unique.
                 name = comp.generateUniqueName(name);
                 frameType = new ClassType(name);
-                frameType.setSourceFile(outerClass.getFile());
+                if (outerClass.getFile() != null)
+                  frameType.setSourceFile(outerClass.getFile());
               }
 	    else
 	      frameType = new ClassType(comp.generateClassName("frame"));
@@ -1242,7 +1250,12 @@ public class LambdaExp extends ScopeExp
 	    Method constructor = comp.getConstructor(frameType, this);
 	    code.emitInvokeSpecial(constructor);
 
-            if (staticLinkField != null)
+            // In a constructor, the closure (this) is not valid until the
+            // end, so it shouldn't be used (presumably it is not used
+            // anyway).
+            // There might be a deeper change that would make this test
+            // unnecessary.
+            if (staticLinkField != null && ! (this instanceof ConstructorExp))
               {
                 code.emitDup(heapFrame.getType());
                 code.emitLoad(closureEnv);
