@@ -23,7 +23,7 @@ import mlsub.typing.lowlevel.Kind;
 /**
    Enumeration of the type constructors in a domain.
 
-   @version $Date: 2004/03/23 20:28:43 $
+   @version $Date: 2005/01/04 21:20:21 $
    @author Daniel Bonniot
 */
 
@@ -152,11 +152,11 @@ public class Enumeration
 	    Engine.Constraint c = (Engine.Constraint) cs.next();
 	    
 	    if (c.hasConstants() && 
-		c != bossa.syntax.PrimitiveType.nullTC.getKind())
+		c != nice.tools.typing.PrimitiveType.nullTC.getKind())
 	      {
-		if(linkDbg)
+		if(linkDbg && Typing.dbg)
 		  Debug.println("Choosing kind " + c + " for " + tag);
-		
+
 		if (tag instanceof MonotypeVar)
 		  Engine.forceKind(tag, c.associatedKind);
 		else
@@ -366,14 +366,9 @@ public class Enumeration
   private static boolean checkClassConstraint(Element var, 
                                               TypeConstructor sol)
   {
-    bossa.syntax.ClassDefinition def = bossa.syntax.ClassDefinition.get(sol);
-    
-    if (def == null)
-      return true;
+    Constraint constraint = bossa.syntax.dispatch.getTypeDefResolvedConstraint(sol);
 
-    Constraint constraint = def.getResolvedConstraint();
-
-    if (constraint == mlsub.typing.Constraint.True)
+    if (mlsub.typing.Constraint.trivial(constraint))
       return true;
 
     if (! (var instanceof Monotype))
@@ -381,8 +376,20 @@ public class Enumeration
 
     Monotype m = (Monotype) var;
 
-    MonotypeConstructor type = 
-      new MonotypeConstructor(sol, def.getTypeParameters());
+    /* We don't want to modify var by reducing its domain, since that would
+       prevent other valid solutions to be discovered later.
+       Therefore we introduce a new tc, since what we want is to test
+       the type parameters.
+
+       Another approach would be to mark/backtrack here. That would at least
+       require to slightly change the marking system, so that the exisisting
+       domain is backed-up and the cloned one is used immediately, since
+       the existing one is held by Satisfier.
+    */
+    TypeConstructor tc = new TypeConstructor(sol.variance);
+    Typing.introduce(tc);
+    MonotypeConstructor type =
+      new MonotypeConstructor(tc, bossa.syntax.dispatch.getTypeDefTypeParameters(sol));
 
     try {
       constraint.enter();
@@ -470,5 +477,5 @@ public class Enumeration
     }
   }
 
-  public static boolean linkDbg;
+  public static boolean linkDbg = bossa.util.Debug.linkTests;
 }
