@@ -17,7 +17,7 @@ import java.util.*;
 /**
    A monomorphic type.
 
-   @version $Date: 2004/03/17 16:55:34 $
+   @version $Date: 2004/07/30 19:08:45 $
    @author Daniel Bonniot (d.bonniot@mail.dotcom.fr)
  */
 abstract public class Monotype implements mlsub.typing.lowlevel.Element
@@ -120,6 +120,15 @@ abstract public class Monotype implements mlsub.typing.lowlevel.Element
     return null;
   }
 
+  boolean isUnknown() { return false; }
+
+  void setUnknown()
+    throws mlsub.typing.lowlevel.Unsatisfiable
+  {
+    mlsub.typing.lowlevel.Engine.leq
+      (TopMonotype.instance, nice.tools.typing.Types.rawType(this));
+  }
+
   /****************************************************************
    * Simplification
    ****************************************************************/
