@@ -171,6 +171,8 @@ public final class MonotypeVar extends Monotype
 
   void reset()
   {
+    unknown = false;
+
     if (persistentKind == null)
       {
         setKind(null);
@@ -198,6 +200,17 @@ public final class MonotypeVar extends Monotype
       }
   }
 
+  private boolean unknown;
+
+  boolean isUnknown() { return unknown; }
+
+  void setUnknown()
+    throws mlsub.typing.lowlevel.Unsatisfiable
+  {
+    super.setUnknown();
+    this.unknown = true;
+  }
+
   /** When this variable is discovered to be of some given kind,
       an equivalent monotype is created. */
   private Monotype equivalent;
