@@ -6,7 +6,7 @@ package mlsub.typing.lowlevel;
    
    @see java.util.BitSet
    
-   @version $Revision: 1.8 $, $Date: 2003/09/06 11:31:10 $
+   @version $Revision: 1.10 $, $Date: 2004/04/17 17:12:11 $
    @author Alexandre Frey
    @author Daniel Bonniot 
    (replaced the underlying java.util.Vector by an array 
@@ -440,14 +440,13 @@ public class BitVector implements Cloneable, java.io.Serializable {
   
   /*
    * If there are some trailing zeros, don't count them
-   * result is greater or equal to 1
    */
   private int nonZeroLength() {
     if (bits1 == null)
       return 1;
     
     int n = bits1.length;
-    while (n > 1 && bits1[n-1] == 0L) { n--; }
+    while (n > 0 && bits1[n-1] == 0L) { n--; }
     return n;
   }
 
@@ -538,16 +537,10 @@ public class BitVector implements Cloneable, java.io.Serializable {
       result.bits0 = bits0;
     else
       {
-	int n = nonZeroLength();
-	if (n <= 1)
-        {
-	  result.bits0 = bits1[0];
-	}
-	else
-	{
-	  result.bits1 = new long[n];
-	  System.arraycopy(bits1, 0, result.bits1, 0, n);
-	}
+	// optim: shrink to nonZeroLength()?
+	int n = length();
+	result.bits1 = new long[n];
+	System.arraycopy(bits1, 0, result.bits1, 0, n);
       }
     return result;
   }
@@ -838,24 +831,14 @@ public class BitVector implements Cloneable, java.io.Serializable {
    **/
   final public void truncate(int newSize) {
     int i = subscript(newSize);
-    if (bits1 == null)
-    {
-      if (i == 0)
-	bits0 &= (1L << (newSize & MASK)) - 1;
-      return;
-    }
-    int bitsLength = nonZeroLength();
-    if (i < bitsLength)
+    int bitsLength = length();
+    if (i < bitsLength) {
       andW(i, (1L << (newSize & MASK)) - 1);
-
-    int newlength = Math.min(bitsLength, i+1);
-
-    if (newlength < bits1.length)
-    {
-      long[] newBits = new long[newlength];
-      System.arraycopy(bits1, 0, newBits, 0, newlength);
-      bits1 = newBits;
+      for (i++; i < bitsLength; i++) {
+        bits1[i] = 0L;
+      }
     }
+    // XXX: should shrink the vector to lower memory usage ?
   }
 
   /**
