@@ -45,7 +45,7 @@ public final class K0 {
   /***********************************************************************
    * Debugging
    ***********************************************************************/
-  public static boolean debugK0 = S.debugK0;
+  public static boolean debugK0 = bossa.util.Debug.K0;
   private static int IDs = 0;
   private int ID = IDs++;
   
@@ -167,7 +167,11 @@ public final class K0 {
     return x >= 0 && x < n && !garbage.get(x);
   }
 
-  
+  void discard(int x)
+  {
+    garbage.set(x);
+  }
+
   /***********************************************************************
    * Pretty printing
    ***********************************************************************/
