@@ -34,7 +34,7 @@ import nice.tools.testsuite.output.*;
  * f();
  * 
  * @author	Alex Greif <a href="mailto:alex.greif@web.de">alex.greif@web.de</a>
- * @version	$Id: TestNice.java,v 1.30 2004/03/02 21:44:27 bonniot Exp $
+ * @version	$Id: TestNice.java,v 1.31 2005/02/23 16:57:57 bonniot Exp $
  */
 
 public class TestNice {
@@ -131,8 +131,16 @@ public class TestNice {
 	 * 
 	 */
 	private static Output _output = new ConsoleOutput();
-	
-	
+
+
+	/**
+		 The <b>home</b> directory of gcc.
+		 If you want to use the system-wide version of gcc on a Unix machine,
+		 this should likely be set to "/usr".
+	*/
+	private static String _gcc = null;
+
+
 	/**
 	 * TODO
 	 * 
@@ -262,6 +270,8 @@ public class TestNice {
 			if(s.startsWith("-")) {
 				if ("-output".equalsIgnoreCase(s))
 					setOutput(args[i++]);
+				else if ("-gcc".equalsIgnoreCase(s))
+					setGcc(args[i++]);
 				else if ("-comment".equalsIgnoreCase(s))
 					_writeComments = true;
 				else if ("-runtime".equalsIgnoreCase(s))
@@ -278,7 +288,7 @@ public class TestNice {
 
 	/**
 	 * Sets the output of the test engine
-	 * 
+	 *
 	 * @param	output	TODO
 	 */
 	private static void setOutput(String output) {
@@ -286,7 +296,7 @@ public class TestNice {
 			_output = new ConsoleOutput();
 			return;
 		}
-		
+
 		output = output.toLowerCase();
 		if (output.endsWith(".html")  ||  output.endsWith(".htm"))
 			try {
@@ -298,6 +308,15 @@ public class TestNice {
 
 
 
+	private static void setGcc(String gcc) {
+		_gcc = gcc;
+
+		// When doing native compilation, we need a jarred runtime
+		if (_runtime == null)
+			_runtime = "share/java/nice.jar";
+	}
+
+
 
 	/**
 	 * Prints the usage of this application.
@@ -517,6 +536,12 @@ public class TestNice {
 
 
 
+	static String getGcc() {
+		return _gcc;
+	}
+
+
+
 	/**
 	 * Returns whether comments should be written to output
 	 * 
